@@ -145,6 +145,8 @@ import javax.xml.datatype.XMLGregorianCalendar;
  *         &lt;element name="userfield18" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="userfield19" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *         &lt;element name="userfield20" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
+ *         &lt;element name="image1" type="{http://www.w3.org/2001/XMLSchema}base64Binary" minOccurs="0"/>
+ *         &lt;element name="image1ContentType" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
  *       &lt;/sequence>
  *     &lt;/restriction>
  *   &lt;/complexContent>
@@ -280,7 +282,9 @@ import javax.xml.datatype.XMLGregorianCalendar;
     "userfield17",
     "userfield18",
     "userfield19",
-    "userfield20"
+    "userfield20",
+    "image1",
+    "image1ContentType"
 })
 public class User {
 
@@ -535,6 +539,10 @@ public class User {
     protected String userfield19;
     @XmlElement(nillable = true)
     protected String userfield20;
+    @XmlElement(name = "image1", nillable = true)
+    protected byte[] image1;
+    @XmlElement(name = "image1ContentType", nillable = true)
+    protected String image1ContentType;
 
     /**
      * Gets the value of the aliases property.
@@ -3562,4 +3570,40 @@ public class User {
         this.userfield20 = value;
     }
 
+    /**
+     * Gets the image1
+     *
+     * @return The image1
+     */
+    public byte[] getImage1() {
+        return image1;
+    }
+
+    /**
+     * Sets the image1
+     *
+     * @param image1 The image1 to set
+     */
+    public void setImage1(byte[] image1) {
+        this.image1 = image1;
+    }
+
+    /**
+     * Gets the image1ContentType
+     *
+     * @return The image1ContentType
+     */
+    public String getImage1ContentType() {
+        return image1ContentType;
+    }
+
+    /**
+     * Sets the image1ContentType
+     *
+     * @param image1ContentType The image1ContentType to set
+     */
+    public void setImage1ContentType(String image1ContentType) {
+        this.image1ContentType = image1ContentType;
+    }
+
 }
